from yozuch.generators.post_item_collection import PostItemCollectionGenerator


class CategoryGenerator(PostItemCollectionGenerator):

    def __init__(self):
        super(CategoryGenerator, self).__init__('categories', 'category', 'category')